<?php

declare (strict_types=1);
namespace DhlVendor\WPDesk\Logger;

use DhlVendor\Monolog\Handler\HandlerInterface;
use DhlVendor\Monolog\Handler\NullHandler;
use DhlVendor\Monolog\Logger;
use DhlVendor\Monolog\Handler\ErrorLogHandler;
use DhlVendor\WPDesk\Logger\WC\WooCommerceHandler;
final class SimpleLoggerFactory implements \DhlVendor\WPDesk\Logger\LoggerFactory
{
    /** @var Settings */
    private $options;
    /** @var string */
    private $channel;
    /** @var Logger */
    private $logger;
    public function __construct(string $channel, \DhlVendor\WPDesk\Logger\Settings $options = null)
    {
        $this->channel = $channel;
        $this->options = $options ?? new \DhlVendor\WPDesk\Logger\Settings();
    }
    public function getLogger($name = null) : \DhlVendor\Monolog\Logger
    {
        if ($this->logger) {
            return $this->logger;
        }
        $logger = new \DhlVendor\Monolog\Logger($this->channel);
        $wc_handler = $this->get_wc_handler();
        if ($this->options->use_wc_log) {
            $logger->pushHandler($wc_handler);
        }
        if ($this->options->use_wp_log || $wc_handler instanceof \DhlVendor\Monolog\Handler\NullHandler) {
            $logger->pushHandler($this->get_wp_handler());
        }
        return $this->logger = $logger;
    }
    private function get_wc_handler() : \DhlVendor\Monolog\Handler\HandlerInterface
    {
        if (\function_exists('wc_get_logger')) {
            return new \DhlVendor\WPDesk\Logger\WC\WooCommerceHandler(\wc_get_logger(), $this->options->level);
        }
        return new \DhlVendor\Monolog\Handler\NullHandler();
    }
    private function get_wp_handler() : \DhlVendor\Monolog\Handler\HandlerInterface
    {
        if (\defined('DhlVendor\\WP_DEBUG_LOG') && WP_DEBUG_LOG) {
            return new \DhlVendor\Monolog\Handler\ErrorLogHandler(\DhlVendor\Monolog\Handler\ErrorLogHandler::OPERATING_SYSTEM, $this->options->level);
        }
        return new \DhlVendor\Monolog\Handler\NullHandler();
    }
}
